pw_assert_HandleFailure

Function pw_assert_HandleFailure 

pub unsafe extern "C" fn pw_assert_HandleFailure() -> !
The crash handler called by asserts and panics when they fail.

Since the default_handler feature is disabled, the application must provide an implementation of this function with the #[no_mangle] attribute.

This function must not return.