macro_rules! debug_ne {
($lhs:expr, $rhs:expr $(,)?) => { ... };
($lhs:expr, $rhs:expr, $($args:expr),* $(,)?) => { ... };
}Expand description
Asserts that two expressions are not equal when debug_assertions are enabled.
If debug_assertions are enabled, this behaves exactly like ne!.
If debug_assertions are disabled, this macro is a no-op.
debug_assertions can be enabled by setting this bazel label to True
@pigweed//pw_assert/rust:debug_assertions.
Examples
let x = 5;
pw_assert::debug_ne!(x as i32, 6 as i32);