macro_rules! ne {
($condition_a:expr, $condition_b:expr $(,)?) => { ... };
($condition_a:expr, $condition_b:expr, $($args:expr),* $(,)?) => { ... };
}Expand description
Asserts that two expressions are not equal (equivalent to assert_ne!).
If the expressions are equal, this macro logs a panic banner, logs the
failure (including the values of the expressions and optional custom
message) at FATAL level using pw_log, and then calls
pw_assert_HandleFailure.
Note that due to pw_log requirements, both expressions must be cast
expressions (e.g., x as i32).
Examples
let x = 5;
pw_assert::ne!(x as i32, 6 as i32);
pw_assert::ne!(x as i32, 6 as i32, "x should not be 6");